#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-4gCBOtnsgTRBAMBlLUvIdV
key:                  stack-2.9.3.1-4gCBOtnsgTRBAMBlLUvIdV
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  f1d84da6679526dadad7f015ae362cfc
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-4gCBOtnsgTRBAMBlLUvIdV
depends:
    Cabal-3.10.3.0 aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-6H4MdlQ9LS5JB7dL181Y6t array-0.5.6.0
    async-2.2.5-BExe3HBSFHr8hii1cT1bvS
    attoparsec-0.14.4-FIfeiNzOKYm3sEc1QPF51Z base-4.18.2.1
    base64-bytestring-1.2.1.0-6srVB7ZKmzD1HZV2AV5j9d
    bytestring-0.11.5.3 casa-client-0.0.3-HtP0tr4MZUTA0HIehdQtrT
    casa-types-0.0.3-8wmyL69Ed2oCxx1uuEI1lE
    colour-2.3.6-AUxOwa0Re963ovR5vIqIeF
    conduit-1.3.6.1-4cc2yOSL2sy5iK6rZQd5vm
    conduit-extra-1.3.8-KyGJKsBlxeR6aLyGVSa94z containers-0.6.7
    crypton-1.0.4-DGMKyUhI3LiKWt7ay9qYrG
    crypton-conduit-0.2.3-FVD4oa2ofTg5d21ycTadwB deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-6e0wBrlA2xu66mkOtGwbe0
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-5yKiUxUc3R4Cn5BuwIn6Cx filepath-1.4.300.1
    fsnotify-0.4.4.0-IUeKGQzKMsZIfGCvGv0UG8
    generic-deriving-1.14.6-89W8tWKmocDFxpcsvKtVjK
    hackage-security-0.6.3.2-CB3Wrsd9Zaj3qQCy2bMoEY
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    hi-file-parser-0.1.8.0-Ip7VI5WjVQ4IeDuveTM8bL
    hpack-0.38.0-GBgYgDWrKma9qYYXp6gKtE hpc-0.6.2.0
    http-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
    http-client-tls-0.3.6.4-LhFztqm7Yl955SnS7vNn0b
    http-conduit-2.3.9.1-3cMmWLkkkkTQL61v9H7Y4
    http-download-0.2.1.0-4Ngrp4jnbYC4HpgYYpo77q
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-81XDczF81SH9DS5CAz7XDI mtl-2.3.1
    mustache-2.4.3.1-JcFyZAk9aPv7G05p9dglWX
    neat-interpolation-0.5.1.4-AMExTIYnCI9E84uKNzmCbp
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-9I3qDpNxi1rBTnWffPMXX3
    pantry-0.8.2.2-9C5OBDLvrqMIn6OcjJfdFr
    path-0.9.6-CG6breuY1qpGvStm5q67Gc
    path-io-1.8.2-J3oPz6svUjz5wY9ouZNltz
    persistent-2.14.5.2-3iklR6qVhbcHkfvtZeVIbd
    persistent-sqlite-2.13.1.1-DfjIP0Qysc26cRpm21EvbJ pretty-1.1.3.6
    primitive-0.9.1.0-3wcULVX324m4b7zw32DKNg process-1.6.19.0
    project-template-0.2.1.0-1NpMoxxXNvX8B58n7hBuOK
    random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p
    retry-0.9.3.1-177rcdLxrcvKXTH0bhulJf
    rio-0.1.24.0-8z6Z4xtsejOAYZQptyiBbv
    rio-prettyprint-0.1.8.0-3GH2Xko1no3DAKBMoLmHK2
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-D1O7CCofCAb4YDJ83dqUtH
    tar-0.5.1.1-86aewOwTvTZJMLaNGPv3eW template-haskell-2.20.0.0
    temporary-1.3-7FXkQQKerYU7UfmRyKNwo9 text-2.0.2
    text-metrics-0.3.3-3AOpgZ4OOzO8hscaLL3xTy
    th-reify-many-0.1.10-HtkUemvLDO6KGiyH523XOw time-1.12.2
    tls-2.0.6-1CZKP97Y3KoB0UoivGsQdY transformers-0.6.1.0
    typed-process-0.2.13.0-40GtvANGP6yKk97Fq1akCj
    unicode-transforms-0.4.0.1-9Um9DDtdyG0KCRhrtai7oD unix-2.8.4.0
    unix-compat-0.7.4.1-DqDzbwuaouv1yXLtKQLq3q
    unliftio-0.2.25.1-2Z0SKAH7tah9jbYwGNfwFX
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
    yaml-0.11.11.2-BS6mG9zOsXWGQgGFfufno4
    zip-archive-0.4.3.2-1XeMNWl5bCBHGBNkq6CyGn
    zlib-0.7.0.0-AoTprguvpA33AfeZgt1J6J

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

